@@ -27,6 +27,8 @@ from oslo_log import log
 from packaging import version
 
 import tobiko
+from tobiko.shell import dns_ping
+from tobiko.shell import dhcp_ping
 from tobiko.shell import files
 from tobiko.shell import ip
 from tobiko.shell import sh
@@ -211,7 +213,6 @@ class UnknownOpenStackConfigurationFile(tobiko.TobikoException):
 
 class OpenStackTopologyNode:
 
-    _docker_client = None
     _podman_client = None
 
     def __init__(self,
@@ -251,15 +252,6 @@ class OpenStackTopologyNode:
     def ssh_parameters(self):
         return self.ssh_client.setup_connect_parameters()
 
-    @property
-    def docker_client(self):
-        docker_client = self._docker_client
-        if not docker_client:
-            from tobiko import docker
-            self._docker_client = docker_client = docker.get_docker_client(
-                ssh_client=self.ssh_client)
-        return docker_client
-
     @property
     def podman_client(self):
         podman_client = self._podman_client
@@ -302,6 +294,7 @@ class OpenStackTopology(tobiko.SharedFixture):
         neutron.METADATA_AGENT: 'devstack@q-meta',
         neutron.OVN_METADATA_AGENT: 'devstack@q-ovn-metadata-agent',
         neutron.NEUTRON_OVN_METADATA_AGENT: 'devstack@q-ovn-metadata-agent',
+        neutron.NEUTRON_OVN_AGENT: 'devstack@q-ovn-agent',
         neutron.OVN_CONTROLLER: 'ovn-controller',
         neutron.OVN_BGP_AGENT: 'ovn-bgp-agent',
         neutron.FRR: 'frr',
@@ -311,8 +304,6 @@ class OpenStackTopology(tobiko.SharedFixture):
 
     has_containers = False
 
-    container_runtime_cmd = 'docker'
-
     config_file_mappings = {
         'ml2_conf.ini': '/etc/neutron/plugins/ml2/ml2_conf.ini',
         'bgp-agent.conf': '/etc/ovn-bgp-agent/bgp-agent.conf'
@@ -325,13 +316,7 @@ class OpenStackTopology(tobiko.SharedFixture):
     file_digger_class: typing.Type[files.LogFileDigger] = \
         files.JournalLogDigger
 
-    # This is dict which handles mapping of the log file and systemd_unit (if
-    # needed) for the OpenStack services.
-    # In case of Devstack topology file name in fact name of the systemd unit
-    # as logs are stored in journalctl
-    log_names_mappings = {
-        neutron.SERVER: 'devstack@q-svc',
-    }
+    log_names_mappings: dict = {}
 
     def __init__(self):
         super(OpenStackTopology, self).__init__()
@@ -342,6 +327,16 @@ class OpenStackTopology(tobiko.SharedFixture):
         self._addresses: typing.Dict[netaddr.IPAddress,
                                      OpenStackTopologyNode] = (
             collections.OrderedDict())
+        # This is dict which handles mapping of the log file and systemd_unit
+        # (if needed) for the OpenStack services.
+        # In case of Devstack topology file name in fact name of the systemd
+        # unit as logs are stored in journalctl
+        if not self.log_names_mappings:
+            self.log_names_mappings = {
+                neutron.SERVER: (
+                    'devstack@' +
+                    tobiko.tobiko_config().topology.devstack_neutron_service)
+            }
 
     def setup_fixture(self):
         self.discover_nodes()
@@ -650,10 +645,51 @@ class OpenStackTopology(tobiko.SharedFixture):
                                        ip_version=self.ip_version,
                                        ssh_config=True)
 
-    def check_or_start_background_vm_ping(self):
+    def check_or_start_background_vm_ping(self, server_ip, ssh_client=None):  # noqa; pylint: disable=W0613
         tobiko.skip_test("Background ping not supported by "
                          "this topology class.")
 
+    def check_or_start_background_iperf_connection(
+            self,
+            server_ip: typing.Union[str, netaddr.IPAddress],  # noqa; pylint: disable=W0613
+            port: int,  # noqa; pylint: disable=W0613
+            protocol: str,  # noqa; pylint: disable=W0613
+            ssh_client: ssh.SSHClientType = None,  # noqa; pylint: disable=W0613
+            iperf3_server_ssh_client: ssh.SSHClientType = None):  # noqa; pylint: disable=W0613
+        tobiko.skip_test("Background iperf not supported by "
+                         "this topology class.")
+
+    def check_or_start_background_http_ping(
+            self,
+            server_ip: typing.Union[str, netaddr.IPAddress],  # noqa; pylint: disable=W0613
+            ssh_client: ssh.SSHClientType = None):  # noqa; pylint: disable=W0613
+        tobiko.skip_test("Background HTTP ping test is not supported by "
+                         "this topology class.")
+
+    def check_or_start_background_dhcp_ping(
+            self,
+            ssh_client: ssh.SSHClientType):
+        sh.check_or_start_external_process(
+            start_function=dhcp_ping.start_dhcp_ping_process,
+            stop_function=dhcp_ping.stop_dhcp_ping_process,
+            liveness_function=dhcp_ping.dhcp_ping_process_alive,
+            check_function=dhcp_ping.check_dhcp_ping_results,
+            ssh_client=ssh_client)
+
+    def check_or_start_background_dns_ping(
+            self,
+            ip_address: typing.Union[str, netaddr.IPAddress],
+            fqdn: str,
+            ssh_client: ssh.SSHClientType):
+        sh.check_or_start_external_process(
+            start_function=dns_ping.start_dns_ping_process,
+            stop_function=dns_ping.stop_dns_ping_process,
+            liveness_function=dns_ping.dns_ping_process_alive,
+            check_function=dns_ping.check_dns_ping_results,
+            ip_address=ip_address,
+            fqdn=fqdn,
+            ssh_client=ssh_client)
+
 
 def get_openstack_topology(topology_class: typing.Type = None) -> \
         OpenStackTopology:
@@ -717,15 +753,15 @@ def get_rhosp_version():
 
 def get_nova_version_from_container():
     ssh_client = list_openstack_nodes(group='controller')[0].ssh_client
-    for container_runtime_cmd in ('docker', 'podman'):
-        try:
-            cmd = (container_runtime_cmd +
-                   ' exec -uroot nova_conductor nova-manage --version')
-            return sh.execute(cmd,
-                              ssh_client=ssh_client,
-                              sudo=True).stdout
-        except sh.ShellCommandFailed:
-            pass
+    container_runtime_cmd = 'podman'
+    try:
+        cmd = (container_runtime_cmd +
+               ' exec -uroot nova_conductor nova-manage --version')
+        return sh.execute(cmd,
+                          ssh_client=ssh_client,
+                          sudo=True).stdout
+    except sh.ShellCommandFailed:
+        pass
 
 
 # During a execution of tobiko, openstack version does not change, so let's
