@@ -18,6 +18,9 @@ from tobiko.podified import _openshift
 from tobiko.podified import containers
 
 
+NOVA_LIBVIRT_CONTAINER = 'nova_compute'
+CONTAINER_RUNTIME = 'podman'
+
 EDPM_NODE = _topology.EDPM_NODE
 OCP_WORKER = _topology.OCP_WORKER
 EDPM_COMPUTE_GROUP = _openshift.EDPM_COMPUTE_GROUP
@@ -32,5 +35,8 @@ skip_if_podified = _topology.skip_if_podified
 get_dataplane_ssh_keypair = _openshift.get_dataplane_ssh_keypair
 has_podified_cp = _openshift.has_podified_cp
 get_ovndbcluter = _openshift.get_ovndbcluter
+execute_in_pod = _openshift.execute_in_pod
+get_openstack_config_secret = _openshift.get_openstack_config_secret
+get_pods = _openshift.get_pods
 
 get_container_runtime_name = containers.get_container_runtime_name
