@@ -15,6 +15,7 @@ from __future__ import absolute_import
 
 import typing
 
+import netaddr
 from oslo_log import log
 
 import tobiko
@@ -24,6 +25,9 @@ from tobiko.podified import _edpm
 from tobiko.podified import _openshift
 from tobiko.podified import containers
 from tobiko import rhosp
+from tobiko.shell import iperf3
+from tobiko.shell import http_ping
+from tobiko.shell import ping
 from tobiko.shell import sh
 from tobiko.shell import ssh
 
@@ -60,6 +64,7 @@ class PodifiedTopology(rhosp.RhospTopology):
         neutron.METADATA_AGENT: 'edpm_neutron_metadata_agent',
         neutron.OVN_METADATA_AGENT: 'edpm_ovn_metadata_agent',
         neutron.NEUTRON_OVN_METADATA_AGENT: 'edpm_ovn_metadata_agent',
+        neutron.NEUTRON_OVN_AGENT: 'edpm_ovn_agent',
         neutron.OVN_CONTROLLER: 'edpm_ovn_controller',
         neutron.OVN_BGP_AGENT: 'edpm_ovn_bgp_agent',
         neutron.FRR: 'edpm_frr'
@@ -73,6 +78,7 @@ class PodifiedTopology(rhosp.RhospTopology):
         neutron.METADATA_AGENT: 'neutron_metadata_agent',
         neutron.OVN_METADATA_AGENT: 'ovn_metadata_agent',
         neutron.NEUTRON_OVN_METADATA_AGENT: 'ovn_metadata_agent',
+        neutron.NEUTRON_OVN_AGENT: 'ovn_agent',
         neutron.OVN_CONTROLLER: 'ovn_controller',
         neutron.OVN_BGP_AGENT: 'ovn_bgp_agent',
         neutron.FRR: 'frr'
@@ -128,8 +134,8 @@ class PodifiedTopology(rhosp.RhospTopology):
     def create_node(self, name, ssh_client, **kwargs):
         node_type = kwargs.pop('node_type')
         if node_type == OCP_WORKER:
-            return OcpWorkerNode(topology=self, name=name, ssh_client=None,
-                                 **kwargs)
+            return OcpNode(topology=self, name=name, ssh_client=None,
+                           **kwargs)
         else:
             return EdpmNode(topology=self, name=name, ssh_client=ssh_client,
                             **kwargs)
@@ -174,6 +180,68 @@ class PodifiedTopology(rhosp.RhospTopology):
                                  node_type=EDPM_NODE)
             assert isinstance(node, EdpmNode)
 
+    def check_or_start_background_vm_ping(
+            self,
+            server_ip: typing.Union[str, netaddr.IPAddress],
+            ssh_client: ssh.SSHClientType = None):
+        if not ssh_client:
+            _openshift.check_or_start_tobiko_ping_command(
+                server_ip=server_ip
+            )
+        else:
+            sh.check_or_start_external_process(
+                start_function=ping.execute_ping_in_background,
+                check_function=ping.check_ping_results,
+                liveness_function=ping.ping_alive,
+                stop_function=ping.stop_ping,
+                address=server_ip,
+                ssh_client=ssh_client)
+
+    def check_or_start_background_iperf_connection(
+            self,
+            server_ip: typing.Union[str, netaddr.IPAddress],
+            port: int,
+            protocol: str,
+            ssh_client: ssh.SSHClientType = None,
+            iperf3_server_ssh_client: ssh.SSHClientType = None):
+
+        kwargs = {
+            'address': server_ip,
+            'port': port,
+            'protocol': protocol,
+            'ssh_client': ssh_client,
+            'iperf3_server_ssh_client': iperf3_server_ssh_client,
+            'check_function': iperf3.check_iperf3_client_results
+        }
+        if not ssh_client:
+            kwargs['start_function'] = _openshift.start_iperf3
+            kwargs['liveness_function'] = _openshift.iperf3_pod_alive
+            kwargs['stop_function'] = _openshift.stop_iperf3_client
+        else:
+            kwargs['start_function'] = \
+                iperf3.execute_iperf3_client_in_background
+            kwargs['liveness_function'] = iperf3.iperf3_client_alive
+            kwargs['stop_function'] = iperf3.stop_iperf3_client
+
+        sh.check_or_start_external_process(**kwargs)
+
+    def check_or_start_background_http_ping(
+            self,
+            server_ip: typing.Union[str, netaddr.IPAddress],  # noqa; pylint: disable=W0613
+            ssh_client: ssh.SSHClientType = None):  # noqa; pylint: disable=W0613
+        if not ssh_client:
+            _openshift.check_or_start_tobiko_http_ping_command(
+                server_ip=server_ip
+            )
+        else:
+            sh.check_or_start_external_process(
+                start_function=http_ping.start_http_ping_process,
+                stop_function=http_ping.stop_http_ping_process,
+                liveness_function=http_ping.http_ping_process_alive,
+                check_function=http_ping.check_http_ping_results,
+                server_ip=server_ip,
+                ssh_client=ssh_client)
+
 
 class EdpmNode(rhosp.RhospNode):
 
@@ -192,8 +260,25 @@ class EdpmNode(rhosp.RhospNode):
         LOG.debug(f"EDPM node {self.name} power is off.")
 
 
-class OcpWorkerNode(rhosp.RhospNode):
-    pass
+class OcpNode(rhosp.RhospNode):
+    def reboot_node(self, reactivate_servers=True):
+        start_time = tobiko.time()
+        _openshift.reboot_ocp_node(self.name)
+        for _ in tobiko.retry(timeout=600, interval=10):
+            try:
+                uptime = _openshift.get_ocp_node_uptime(self.name)
+            except Exception:
+                LOG.warning(f"Unable to get uptime from node {self.name}")
+            else:
+                elapsed_time = tobiko.time() - start_time
+                if uptime < elapsed_time:
+                    LOG.debug(f"OCP node {self.name} rebooted in "
+                              f"{elapsed_time} seconds.")
+                    break
+                else:
+                    LOG.debug(f"OCP node {self.name} still not rebooted "
+                              f"{elapsed_time} seconds after reboot operation "
+                              f"(uptime={uptime})")
 
 
 def setup_podified_topology():
