@@ -48,15 +48,39 @@ RESTART = "restart"
 
 class BaseAgentTest(testtools.TestCase):
 
-    agent_name: str = '<undefined agent name>'
+    _agent_name: typing.Union[str, typing.List[str]] = '<undefined agent name>'
 
     @classmethod
     def setUpClass(cls):
+        cls.agent_name: str = cls._get_agent_name()
         cls.service_name: str = topology.get_agent_service_name(cls.agent_name)
         cls.container_name: str = ''
         cls.agents: AgentListType = \
             neutron.list_networking_agents(binary=cls.agent_name)
 
+    @classmethod
+    def _get_agent_name(cls) -> str:
+        """Return the valid class agent
+
+        In case of defining more than one possible agent (OVN Metadata agent,
+        OVN agent), this class first retrieves the agent list and determines
+        which one applies. Some agents, like the ones provided in the example,
+        are interchangeable but only one can be running.
+
+        If no agent is listed, the returned name will be first one provided;
+        the class logic will skip the test later.
+        """
+        if isinstance(cls._agent_name, str):
+            return cls._agent_name
+
+        for _agent_name in cls._agent_name:
+            if neutron.has_networking_agents(binary=_agent_name):
+                return _agent_name
+
+        # Default the agent name to the first one in the list, but none of the
+        # provided agent names are present in the system.
+        return cls._agent_name[0]
+
     def setUp(self):
         super(BaseAgentTest, self).setUp()
         if not self.agents:
@@ -189,7 +213,7 @@ class BaseAgentTest(testtools.TestCase):
             self, hosts: typing.Optional[typing.List[str]] = None):
         '''Restart network agent containers on hosts
 
-        Restart docker or podman containers and check network agents are up and
+        Restart podman containers and check network agents are up and
         running after it
 
         :parm hosts: List of hostnames to start agent on
@@ -385,7 +409,7 @@ class BaseAgentTest(testtools.TestCase):
 
 class DHCPAgentTest(BaseAgentTest):
 
-    agent_name = neutron.DHCP_AGENT
+    _agent_name = neutron.DHCP_AGENT
 
     #: Resources stack with Nova server to send messages to
     stack = tobiko.required_fixture(stacks.CirrosServerStackFixture)
@@ -438,7 +462,7 @@ class DHCPAgentTest(BaseAgentTest):
 
 class L3AgentTest(BaseAgentTest):
 
-    agent_name = neutron.L3_AGENT
+    _agent_name = neutron.L3_AGENT
 
     #: Resources stack with Nova server to send messages to
     stack = tobiko.required_fixture(stacks.CirrosPeerServerStackFixture)
@@ -450,7 +474,7 @@ class L3AgentTest(BaseAgentTest):
 
     def wait_for_active_ha_l3_agent(self) -> AgentType:
         ha_router_id = self.ha_stack.network_stack.gateway_id
-        for attempt in tobiko.retry(timeout=180., interval=5.):
+        for attempt in tobiko.retry(timeout=180., interval=3.):
             agents = neutron.list_l3_agent_hosting_routers(ha_router_id)
             try:
                 active_agent = agents.with_items(ha_state='active').unique
@@ -581,7 +605,7 @@ class L3AgentTest(BaseAgentTest):
 
 class OpenVSwitchAgentTest(BaseAgentTest):
 
-    agent_name = neutron.OPENVSWITCH_AGENT
+    _agent_name = neutron.OPENVSWITCH_AGENT
 
     #: Resources stack with Nova server to send messages to
     stack = tobiko.required_fixture(stacks.CirrosServerStackFixture)
@@ -607,7 +631,7 @@ class OpenVSwitchAgentTest(BaseAgentTest):
 
 class OvnControllerTest(BaseAgentTest):
 
-    agent_name = neutron.OVN_CONTROLLER
+    _agent_name = neutron.OVN_CONTROLLER
 
     #: Resources stack with Nova server to send messages to
     stack = tobiko.required_fixture(stacks.CirrosServerStackFixture)
@@ -637,7 +661,7 @@ class OvnControllerTest(BaseAgentTest):
         '''Stop OVN controller container by killing ovn-controller process
         running into it
 
-        Docker/Podman service should restart it automatically
+        Podman service should restart it automatically
 
         :parm hosts: List of hostnames to stop agent on
         :type hosts: list of strings
@@ -820,7 +844,7 @@ class MetadataAgentTest(BaseAgentTest):
     #: Resources stack with Nova server to send messages to
     stack = tobiko.required_fixture(stacks.CirrosServerStackFixture)
 
-    agent_name = neutron.METADATA_AGENT
+    _agent_name: typing.Union[str, typing.List[str]] = neutron.METADATA_AGENT
 
     def wait_for_metadata_status(self, count=None, timeout=60., interval=2.,
                                  is_reachable: typing.Optional[bool] = None):
@@ -908,7 +932,10 @@ class MetadataAgentTest(BaseAgentTest):
 # Search for the corresponding container instead of the networking agent
 class OvnMetadataAgentTest(MetadataAgentTest):
 
-    agent_name = neutron.NEUTRON_OVN_METADATA_AGENT
+    _agent_name = [
+        neutron.NEUTRON_OVN_METADATA_AGENT,
+        neutron.NEUTRON_OVN_AGENT,
+    ]
 
     def setUp(self):
         self.get_ovn_agents_from_containers()
